@@ -2,12 +2,12 @@
 This is the base class on which to build a hierarchical category-like model
 with customizable metadata and its own name space.
 """
+import sys
 
 from django.contrib import admin
 from django.db import models
 from django import forms
-from django.utils.encoding import force_text, python_2_unicode_compatible
-from django.utils.translation import ugettext_lazy as _
+from django.utils.encoding import force_text
 
 from mptt.models import MPTTModel
 from mptt.fields import TreeForeignKey
@@ -17,6 +17,15 @@ from slugify import slugify
 from .editor.tree_editor import TreeEditor
 from .settings import ALLOW_SLUG_CHANGE, SLUG_TRANSLITERATOR
 
+from django.utils.translation import ugettext_lazy as _
+
+
+if sys.version_info[0] < 3:  # Remove this after dropping support of Python 2
+    from django.utils.encoding import python_2_unicode_compatible
+else:
+    def python_2_unicode_compatible(x):
+        return x
+
 
 class CategoryManager(models.Manager):
     """
@@ -37,10 +46,12 @@ class CategoryBase(MPTTModel):
     """
     parent = TreeForeignKey(
         'self',
+        on_delete=models.CASCADE,
         blank=True,
         null=True,
         related_name='children',
-        verbose_name=_('parent'))
+        verbose_name=_('parent'),
+    )
     name = models.CharField(max_length=100, verbose_name=_('name'))
     slug = models.SlugField(verbose_name=_('slug'))
     active = models.BooleanField(default=True, verbose_name=_('active'))
@@ -111,7 +122,11 @@ class CategoryBaseAdminForm(forms.ModelForm):
 
         if self.cleaned_data.get('parent', None) is None or self.instance.id is None:
             return self.cleaned_data
-        decendant_ids = self.instance.get_descendants().values_list('id', flat=True)
+        if self.instance.pk:
+            decendant_ids = self.instance.get_descendants().values_list('id', flat=True)
+        else:
+            decendant_ids = []
+
         if self.cleaned_data['parent'].id == self.instance.id:
             raise forms.ValidationError(_("You can't set the parent of the "
                                           "item to itself."))
