@@ -4,7 +4,7 @@ import django
 DJANGO10_COMPAT = django.VERSION[0] < 1 or (django.VERSION[0] == 1 and django.VERSION[1] < 1)
 
 STATIC_URL = getattr(settings, 'STATIC_URL', settings.MEDIA_URL)
-if STATIC_URL == None:
+if STATIC_URL is None:
     STATIC_URL = settings.MEDIA_URL
 MEDIA_PATH = getattr(settings, 'EDITOR_MEDIA_PATH', '%seditor/' % STATIC_URL)
 
