@@ -16,9 +16,10 @@ class CategoryFKField(ForeignKey):
             kwargs.pop('to')
         super(CategoryFKField, self).__init__(to=Category, **kwargs)
 
+
 try:
     from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], ["^categories\.fields\.CategoryFKField"])
-    add_introspection_rules([], ["^categories\.fields\.CategoryM2MField"])
+    add_introspection_rules([], [r"^categories\.fields\.CategoryFKField"])
+    add_introspection_rules([], [r"^categories\.fields\.CategoryM2MField"])
 except ImportError:
     pass
