@@ -2,7 +2,7 @@ from django import template
 from django.apps import apps
 from django.template import (Node, TemplateSyntaxError, VariableDoesNotExist)
 from django.template.base import FilterExpression
-from django.utils.six import string_types
+from six import string_types
 from categories.base import CategoryBase
 from categories.models import Category
 from mptt.utils import drilldown_tree_for_node
@@ -86,7 +86,7 @@ class CategoryDrillDownNode(template.Node):
                 context[self.varname] = drilldown_tree_for_node(cat)
             else:
                 context[self.varname] = []
-        except:
+        except Exception:
             context[self.varname] = []
         return ''
 
@@ -338,6 +338,7 @@ def do_get_latest_objects_by_category(parser, token):
         num = FilterExpression(None, parser)
     return LatestObjectsNode(var_name, category, app_label, model_name, set_name, date_field, num)
 
+
 register.tag("get_latest_objects_by_category", do_get_latest_objects_by_category)
 
 
